
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% preprocess_fmr.m
% Preprocess a previously created functional data file (*.fmr). Here we open the "CG_OBJECTS_SCRIPT.fmr" file.
% Data: BrainVoyager Getting Started Guide 4
% Works with BrainVoyager 22
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
bv = actxserver('BrainVoyager.BrainVoyagerScriptAccess.1')
[FileName PathName] = uigetfile('*.fmr') % invoke file dialog
docFMR = bv.OpenDocument([PathName FileName]);
% Set spatial and temporal parameters relevant for preprocessing
% This can be skipped if these values are set when reading the data
% To check whether these values have been set already (i.e. from header),
% use the "VoxelResolutionVerified" and "TimeResolutionVerified" properties
if ~docFMR.TimeResolutionVerified
    docFMR.TR = 2000;
    docFMR.InterSliceTime = 31;
    docFMR.TimeResolutionVerified = 1;
end
if ~docFMR.VoxelResolutionVerified
    docFMR.PixelSizeOfSliceDimX = 2.0;
    docFMR.PixelSizeOfSliceDimY = 2.0;
    docFMR.SliceThickness = 2.0;
    docFMR.GapThickness = 0.0;
    docFMR.VoxelResolutionVerified = 1;
end
% We save the new settings into the FMR file
docFMR.Save;
% Preprocessing step 1: mean intensity adjustment (optional)
docFMR.AdjustMeanIntensity();
ResultFileName = docFMR.FileNameOfPreprocessdFMR;
docFMR.Close;
docFMR = bv.OpenDocument( ResultFileName );
% Preprocessing step 2: Slice time correction
if (docFMR.HasSliceTimeTable)
    docFMR.CorrectSliceTimingUsingTimeTable(1); % 1: cubic spline interpolation
else
    docFMR.CorrectSliceTiming( 2, 0 ); % GSG4: ascending interleaved 2, MB 2
% First param: Scan order 0 -> Ascending, 1 -> Asc-Interleaved, 2 -> Asc-Int2,
% 10 -> Descending, 11 -> Desc-Int, 12 -> Desc-Int2
% Second param: Interpolation method: 0 -> trilinear, 1 -> sinc
end
ResultFileName = docFMR.FileNameOfPreprocessdFMR;
docFMR.Close;
docFMR = bv.OpenDocument( ResultFileName );
% Preprocessing step 3: 3D motion correction
docFMR.CorrectMotion(1);
ResultFileName = docFMR.FileNameOfPreprocessdFMR;
% the current doc (input FMR) knows the name of the automatically saved output FMR
docFMR.Remove; % close or remove input FMR
bv.PrintToLog('Removed slice scan time corrected files instead of just closing...')
% docFMR.Close(); // close input FMR
docFMR = bv.OpenDocument( ResultFileName );
% Open motion corrected file (output FMR) and assign to our doc var
% Preprocessing step 4: Spatial Gaussian Smoothing (not recommended
% for individual analysis with a 64x64 matrix)
docFMR.SpatialGaussianSmoothing( 4, 'mm'); % FWHM value and unit
ResultFileName = docFMR.FileNameOfPreprocessdFMR;
docFMR.Close; % docFMR.Remove(); % close or remove input FMR
docFMR = bv.OpenDocument( ResultFileName );
% Preprocessing step 5: Temporal High Pass Filter, includes Linear Trend
% Removal
docFMR.TemporalHighPassFilterGLMFourier(3);% cycles
ResultFileName = docFMR.FileNameOfPreprocessdFMR;
docFMR.Close; % docFMR.Remove(); // close or remove input FMR
docFMR = bv.OpenDocument( ResultFileName );
% Preprocessing step 6: Temporal Gaussian Smoothing (not recommended for
% event-related data)
docFMR.TemporalGaussianSmoothing( 3, 's'); % default value in BV
ResultFileName = docFMR.FileNameOfPreprocessdFMR;
docFMR.Close; % docFMR.Remove(); % close or remove input FMR
docFMR = bv.OpenDocument( ResultFileName );
